@@ -393,7 +393,6 @@ func TestPGFlexFailover(t *testing.T) {
 	fmt.Println(newLeaderMachineID)
 	fmt.Println(leaderMachineID)
 	require.NotEqual(t, newLeaderMachineID, leaderMachineID, "Failover failed! PG Leader didn't change!")
-
 }
 
 func TestAppsV2_PostgresNoMachines(t *testing.T) {
@@ -799,3 +798,18 @@ func TestNoPublicIPDeployMachines(t *testing.T) {
 	// There should be no ips allocated
 	require.Equal(f, "[]\n", result.StdOut().String())
 }
+
+func TestLaunchCpusMem(t *testing.T) {
+	var (
+		f       = testlib.NewTestEnvFromEnv(t)
+		appName = f.CreateRandomAppName()
+	)
+
+	f.Fly("launch --org %s --name %s --region %s --now --internal-port 80 --image nginx --auto-confirm --vm-cpus 4 --vm-memory 8192 --vm-cpukind performance", f.OrgSlug(), appName, f.PrimaryRegion())
+	machines := f.MachinesList(appName)
+	firstMachineGuest := machines[0].Config.Guest
+
+	require.Equal(f, 4, firstMachineGuest.CPUs)
+	require.Equal(f, 8192, firstMachineGuest.MemoryMB)
+	require.Equal(f, "performance", firstMachineGuest.CPUKind)
+}
